Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1231)

Unified Diff: mojo/public/js/validation_unittests.js

Issue 951573002: Add validation test cases for struct versioning. (Closed) Base URL: https://github.com/domokit/mojo.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mojo/public/js/validation_unittests.js
diff --git a/mojo/public/js/validation_unittests.js b/mojo/public/js/validation_unittests.js
index 8a1f385f4518403b7c8ac7cad64d1571f9b6ad57..a04879cd4b00f3bda1d466b88837bcdcae35371d 100644
--- a/mojo/public/js/validation_unittests.js
+++ b/mojo/public/js/validation_unittests.js
@@ -225,8 +225,11 @@ define([
expect(testFiles.length).toBeGreaterThan(0);
for (var i = 0; i < testFiles.length; i++) {
- // TODO(hansmuller): Temporarily skipping array pointer overflow tests.
- if (testFiles[i].indexOf("overflow") != -1) {
+ // TODO(hansmuller, yzshen): Temporarily skipping:
+ // - array pointer overflow tests;
+ // - struct versioning tests (tests with "mthd11" in the name).
+ if (testFiles[i].indexOf("overflow") != -1 ||
+ testFiles[i].indexOf("mthd11") != -1) {
console.log("[Skipping " + testFiles[i] + "]");
continue;
}
@@ -249,11 +252,6 @@ define([
testInterface.ConformanceTestInterface.validateRequest]);
}
- function testNotImplementedMessageValidation() {
- testMessageValidation("not_implemented_", [
- testInterface.ConformanceTestInterface.validateRequest]);
- }
-
function testIntegratedMessageValidation(testFilesPattern) {
var testFiles = getMessageTestFiles(testFilesPattern);
expect(testFiles.length).toBeGreaterThan(0);
« no previous file with comments | « mojo/public/interfaces/bindings/tests/validation_test_interfaces.mojom ('k') | mojo/python/tests/validation_unittest.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698